"""
Ephemeral Task Manager tools for managing a list of tasks.

This module provides tools for appending, prepending, inserting, starting, completing, and listing tasks.
Tasks follow a state machine that transitions from PENDING through IN_PROGRESS to COMPLETED.
"""

from mojentic.llm.tools.ephemeral_task_manager.append_task_tool import AppendTaskTool
from mojentic.llm.tools.ephemeral_task_manager.clear_tasks_tool import ClearTasksTool
from mojentic.llm.tools.ephemeral_task_manager.complete_task_tool import CompleteTaskTool
from mojentic.llm.tools.ephemeral_task_manager.insert_task_after_tool import InsertTaskAfterTool
from mojentic.llm.tools.ephemeral_task_manager.list_tasks_tool import ListTasksTool
from mojentic.llm.tools.ephemeral_task_manager.prepend_task_tool import PrependTaskTool
from mojentic.llm.tools.ephemeral_task_manager.start_task_tool import StartTaskTool
from mojentic.llm.tools.ephemeral_task_manager.ephemeral_task_list import EphemeralTaskList, Task

__all__ = [
    "EphemeralTaskList",
    "Task",
    "AppendTaskTool",
    "PrependTaskTool",
    "InsertTaskAfterTool",
    "StartTaskTool",
    "CompleteTaskTool",
    "ListTasksTool",
    "ClearTasksTool",
]



import json

from mojentic.llm.gateways.models import TextContent


class LLMTool:
    def run(self, **kwargs):
        raise NotImplementedError

    def call_tool(self, **kwargs):
        result = self.run(**kwargs)
        if isinstance(result, dict):
            result = json.dumps(result)
        return {
            "content": [
                TextContent(type="text", text=result).model_dump(),
            ]
        }

    @property
    def descriptor(self):
        raise NotImplementedError

    @property
    def name(self):
        return self.descriptor["function"]["name"]

    @property
    def description(self):
        return self.descriptor["function"]["description"]

    def matches(self, name: str):
        return name == self.name
